@@ -81,8 +81,8 @@ class CredmgrProxy:
                                                                project_name=project_name,
                                                                scope=scope)
 
-            id_token = api_response.value.get(self.ID_TOKEN, None)
-            refresh_token = api_response.value.get(self.REFRESH_TOKEN, None)
+            id_token = api_response.get(self.ID_TOKEN, None)
+            refresh_token = api_response.get(self.REFRESH_TOKEN, None)
             return Status.OK, id_token, refresh_token
         except CredMgrException as e:
             message = str(e.body)
